.. _spider_atv.at:

atv.at
------
Get newest episodes of TV shows from `ATV.at <https://www.atv.at>`_.

Configuration
~~~~~~~~~~~~~
Add ``atv.at`` to the list of spiders:

.. code-block:: ini

   # List of spiders to run by default, one per line.
   spiders =
     atv.at

